==> me-func-pkg-0.0.5.tgz: package/index.js <==
'use strict';
const axios = require('axios');

module.exports = {
  serviceSend,
  serviceNames: Object.freeze({
    ASK_SERVICE: 'ask_service',
    AUDIOBOOK_SERVICE: 'audio_service',
    BLOG_SERVICE: 'blog_service',
    BUSINESS_SERVICE: 'business_service',
    CHAT_SERVICE: 'chat_service',
    COURSE_SERVICE: 'course_service',
    FILE_SERVICE: 'file_service',
    POST_SERVICE: 'post_service',
    GLOBAL_SERVICE: 'global_service',
    NOTIFICATION_SERVICE: 'notification_service',
    PAYMENT_SERVICE: 'payment_service',
    POST_SERVICE: 'post_service',
    STORY_SERVICE: 'story_service',
    USER_SERVICE: 'user_service',
  }),
  serviceUrls: Object.freeze({
    ask_service: {
      REAL_URL: 'http://ask-srv:3000/api',
      LOCAL_URL: 'http://localhost:3012/api',
    },
    audio_service: {
      REAL_URL: 'http://audio-srv:3000/api',
      LOCAL_URL: 'http://localhost:3005/api',
    },
    blog_service: {
      REAL_URL: 'http://blog-srv:3000/api',
      LOCAL_URL: 'http://localhost:3010/api',
    },
    business_service: {
      REAL_URL: 'http://business-srv:3000/api',
      LOCAL_URL: 'http://localhost:3008/api',
    },
    chat_service: {
      REAL_URL: 'http://chat-srv:3000/api',
      LOCAL_URL: 'http://localhost:3003/api',
    },
    course_service: {
      REAL_URL: 'http://course-srv:3000/api',
      LOCAL_URL: 'http://localhost:3010/api',
    },
    file_service: {
      REAL_URL: 'http://file-srv:3000/api',
      LOCAL_URL: 'http://localhost:3006/api',
    },
    global_service: {
      REAL_URL: 'http://global-srv:3000/api',
      LOCAL_URL: 'http://localhost:3013/api',
    },
    notification_service: {
      REAL_URL: 'http://notification-srv:3000/api',
      LOCAL_URL: 'http://localhost:3001/api',
    },
    payment_service: {
      REAL_URL: 'http://payment-srv:3000/api',
      LOCAL_URL: 'http://localhost:3002/api',
    },
    post_service: {
      REAL_URL: 'http://post-srv:3000/api',
      LOCAL_URL: 'http://localhost:3011/api',
    },
    socket_chat_service: {
      REAL_URL: 'http://socket-chat-srv:3000/api',
      LOCAL_URL: 'http://localhost:4001/api',
    },
    socket_log_service: {
      REAL_URL: 'http://socket-log-srv:3000/api',
      LOCAL_URL: 'http://localhost:4002/api',
    },
    story_service: {
      REAL_URL: 'http://story-srv:3000/api',
      LOCAL_URL: 'http://localhost:3004/api',
    },
    user_service: {
      REAL_URL: 'http://user-srv:3000/api',
      LOCAL_URL: 'http://localhost:3000/api',
    },
  }),
};

function isCheckObject(service_url, serviceMode, path) {
  try {
    if (!service_url || (service_url && service_url.constructor !== Object))
      throw new Error('Object not found');

    return `${service_url[serviceMode]}/${path}`;
  } catch (err) {
    console.error('error isObjectCheck', err);
    return err;
  }
}

/**
 * service axios send
 * @param enum type
 * @param PROCESS_ENV serviceMode || null
 * @param Object data
 * @param String path
 * @returns response
 */
function serviceSend(type, sMode, data, path) {
  try {
    const { SERVICE_MODE } = process.env;

    const serviceMode = SERVICE_MODE;
    const url = isCheckObject(
      module.exports.serviceUrls[type],
      serviceMode,
      path
    );
    const config = {
      method: 'post',
      url: url,
      headers: {
        'Content-Type': 'application/json',
        'X-Requested-With': 'XMLHttpRequest',
      },
      data: { doc: data },
    };

    return new Promise(async (resolve, reject) => {
      await axios(config)
        .then((response) => {
          resolve(response);
        })
        .catch((err) => {
          reject(err);
        });
    });
  } catch (err) {
    console.error('err', err);
    return err.message;
  }
}

==> me-func-pkg-0.0.6.tgz: package/index.js <==
'use strict';
const axios = require('axios');

module.exports = {
  serviceSend,
  serviceNames: Object.freeze({
    ASK_SERVICE: 'ask_service',
    AUDIOBOOK_SERVICE: 'audio_service',
    BLOG_SERVICE: 'blog_service',
    BUSINESS_SERVICE: 'business_service',
    CHAT_SERVICE: 'chat_service',
    COURSE_SERVICE: 'course_service',
    FILE_SERVICE: 'file_service',
    POST_SERVICE: 'post_service',
    GLOBAL_SERVICE: 'global_service',
    NOTIFICATION_SERVICE: 'notification_service',
    PAYMENT_SERVICE: 'payment_service',
    POST_SERVICE: 'post_service',
    STORY_SERVICE: 'story_service',
    USER_SERVICE: 'user_service',
  }),
  serviceUrls: Object.freeze({
    ask_service: {
      REAL_URL: 'http://ask-srv:3000/api',
      LOCAL_URL: 'http://localhost:3012/api',
    },
    audio_service: {
      REAL_URL: 'http://audio-srv:3000/api',
      LOCAL_URL: 'http://localhost:3005/api',
    },
    blog_service: {
      REAL_URL: 'http://blog-srv:3000/api',
      LOCAL_URL: 'http://localhost:3010/api',
    },
    business_service: {
      REAL_URL: 'http://business-srv:3000/api',
      LOCAL_URL: 'http://localhost:3008/api',
    },
    chat_service: {
      REAL_URL: 'http://chat-srv:3000/api',
      LOCAL_URL: 'http://localhost:3003/api',
    },
    course_service: {
      REAL_URL: 'http://course-srv:3000/api',
      LOCAL_URL: 'http://localhost:3010/api',
    },
    file_service: {
      REAL_URL: 'http://file-srv:3000/api',
      LOCAL_URL: 'http://localhost:3006/api',
    },
    global_service: {
      REAL_URL: 'http://global-srv:3000/api',
      LOCAL_URL: 'http://localhost:3013/api',
    },
    notification_service: {
      REAL_URL: 'http://notification-srv:3000/api',
      LOCAL_URL: 'http://localhost:3001/api',
    },
    payment_service: {
      REAL_URL: 'http://payment-srv:3000/api',
      LOCAL_URL: 'http://localhost:3002/api',
    },
    post_service: {
      REAL_URL: 'http://post-srv:3000/api',
      LOCAL_URL: 'http://localhost:3011/api',
    },
    socket_chat_service: {
      REAL_URL: 'http://socket-chat-srv:3000/api',
      LOCAL_URL: 'http://localhost:4001/api',
    },
    socket_log_service: {
      REAL_URL: 'http://socket-log-srv:3000/api',
      LOCAL_URL: 'http://localhost:4002/api',
    },
    story_service: {
      REAL_URL: 'http://story-srv:3000/api',
      LOCAL_URL: 'http://localhost:3004/api',
    },
    user_service: {
      REAL_URL: 'http://user-srv:3000/api',
      LOCAL_URL: 'http://localhost:3000/api',
    },
  }),
};

function isCheckObject(service_url, serviceMode, path) {
  try {
    if (!service_url || (service_url && service_url.constructor !== Object))
      throw new Error('Object not found');

    return `${service_url[serviceMode]}/${path}`;
  } catch (err) {
    console.error('error isObjectCheck', err);
    return err;
  }
}

/**
 * service axios send
 * @param enum type
 * @param PROCESS_ENV serviceMode || null
 * @param Object data
 * @param String path
 * @returns response
 */
function serviceSend(type, data, path) {
  try {
    const { SERVICE_MODE } = process.env;

    const serviceMode = SERVICE_MODE;
    const url = isCheckObject(
      module.exports.serviceUrls[type],
      serviceMode,
      path
    );
    const config = {
      method: 'post',
      url: url,
      headers: {
        'Content-Type': 'application/json',
        'X-Requested-With': 'XMLHttpRequest',
      },
      data: { doc: data },
    };

    return new Promise(async (resolve, reject) => {
      await axios(config)
        .then((response) => {
          resolve(response);
        })
        .catch((err) => {
          reject(err);
        });
    });
  } catch (err) {
    console.error('err', err);
    return err.message;
  }
}
